@@ -7,7 +7,6 @@ import sys
 import textwrap
 from traceback import format_exc
 
-
 def abort(msg):
     """
     Abort execution, print ``msg`` to stderr and exit with error status (1.)
@@ -19,10 +18,15 @@ def abort(msg):
     .. _sys.exit: http://docs.python.org/library/sys.html#sys.exit
     .. _SystemExit: http://docs.python.org/library/exceptions.html#exceptions.SystemExit
     """
-    from fabric.state import output
+    from fabric.state import output, env
+    if not env.colorize_errors:
+        red  = lambda x: x
+    else:
+        from colors import red
+
     if output.aborts:
-        sys.stderr.write("\nFatal error: %s\n" % str(msg))
-        sys.stderr.write("\nAborting.\n")
+        sys.stderr.write(red("\nFatal error: %s\n" % str(msg)))
+        sys.stderr.write(red("\nAborting.\n"))
     sys.exit(1)
 
 
@@ -35,9 +39,15 @@ def warn(msg):
     provided that the ``warnings`` output level (which is active by default) is
     turned on.
     """
-    from fabric.state import output
+    from fabric.state import output, env
+
+    if not env.colorize_errors:
+        magenta = lambda x: x
+    else:
+        from colors import magenta
+
     if output.warnings:
-        sys.stderr.write("\nWarning: %s\n\n" % msg)
+        sys.stderr.write(magenta("\nWarning: %s\n\n" % msg))
 
 
 def indent(text, spaces=4, strip=False):
@@ -249,8 +259,7 @@ def _pty_size():
         import termios
         import struct
 
-    default_rows, default_cols = 24, 80
-    rows, cols = default_rows, default_cols
+    rows, cols = 24, 80
     if not win32 and sys.stdout.isatty():
         # We want two short unsigned integers (rows, cols)
         fmt = 'HH'
@@ -263,11 +272,6 @@ def _pty_size():
                 buffer)
             # Unpack buffer back into Python data types
             rows, cols = struct.unpack(fmt, result)
-            # Fall back to defaults if TIOCGWINSZ returns unreasonable values
-            if rows == 0:
-                rows = default_rows
-            if cols == 0:
-                cols = default_cols
         # Deal with e.g. sys.stdout being monkeypatched, such as in testing.
         # Or termios not having a TIOCGWINSZ.
         except AttributeError:
